// This file is part of Parlera.
//
// Parlera is free software: you can redistribute it and/or modify
// it under the terms of the GNU Affero General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version. As an additional permission under
// section 7, you are allowed to distribute the software through an app
// store, even if that store has restrictive terms and conditions that
// are incompatible with the AGPL, provided that the source is also
// available under the AGPL with or without this permission through a
// channel without those restrictive terms and conditions.
//
// Parlera is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU Affero General Public License for more details.
//
// You should have received a copy of the GNU Affero General Public License
// along with Parlera.  If not, see <http://www.gnu.org/licenses/>.
//
// This file is derived from work covered by the following license notice:
//
//   Copyright 2021 Kamil Rykowski, Kamil Lewandowski, and Ewa Osiecka
//
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//       http://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.

import 'package:audioplayers/audioplayers.dart';
import 'package:flutter/widgets.dart';
import 'package:parlera/store/settings.dart';

class AudioHelper {
  //todo might want to downgrade to 1.0.0 because of
  //todo test on Linux
  static final _player = AudioPlayer();
  static final _soundIncorrect = AssetSource('audio/choice_incorrect.wav');
  static final _soundCorrect = AssetSource('audio/choice_correct.wav');
  static final _soundCountdown = AssetSource('audio/countdown.wav');
  static final _soundStart = AssetSource('audio/start.wav');
  static final _soundCountdownStart = AssetSource('audio/countdown_start.wav');

  // static AudioCache audioCache = AudioCache(prefix: 'assets/audio/');

  static bool _audioEnabled(BuildContext context) =>
      SettingsModel.of(context).isAudioEnabled;

  static void playIncorrect(context) {
    if (_audioEnabled(context)) {
      _player.play(_soundIncorrect);
      _player
          .stop(); //todo this is temporary, due to https://github.com/bluefireteam/audioplayers/issues/1165
    }
  }

  static void playCorrect(context) {
    if (_audioEnabled(context)) {
      _player.play(_soundCorrect);
      _player
          .stop(); //todo this is temporary, due to https://github.com/bluefireteam/audioplayers/issues/1165
    }
  }

  static void playCountdown(context) {
    if (_audioEnabled(context)) {
      _player.play(_soundCountdown);
      _player
          .stop(); //todo this is temporary, due to https://github.com/bluefireteam/audioplayers/issues/1165
    }
  }

  static void playStart(context) {
    if (_audioEnabled(context)) {
      _player.play(_soundStart);
      _player
          .stop(); //todo this is temporary, due to https://github.com/bluefireteam/audioplayers/issues/1165
    }
  }

  static void playCountdownStart(context) {
    if (_audioEnabled(context)) {
      _player.play(_soundCountdownStart);
      _player
          .stop(); //todo this is temporary, due to https://github.com/bluefireteam/audioplayers/issues/1165
    }
  }
}
